Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(329)

Unified Diff: remoting/protocol/channel_socket_adapter.h

Issue 1197853003: Add P2PDatagramSocket and P2PStreamSocket interfaces. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/protocol/channel_socket_adapter.h
diff --git a/remoting/protocol/channel_socket_adapter.h b/remoting/protocol/channel_socket_adapter.h
index 9af85e2b96bd6f3992e26da1f6a9020b8f789527..8d455d26409d571e162a793b924393738db46cc6 100644
--- a/remoting/protocol/channel_socket_adapter.h
+++ b/remoting/protocol/channel_socket_adapter.h
@@ -8,7 +8,7 @@
#include "base/callback_forward.h"
#include "base/compiler_specific.h"
#include "base/threading/thread_checker.h"
-#include "net/socket/socket.h"
+#include "remoting/protocol/p2p_socket.h"
#include "third_party/webrtc/base/asyncpacketsocket.h"
#include "third_party/webrtc/base/sigslot.h"
#include "third_party/webrtc/base/socketaddress.h"
@@ -20,10 +20,10 @@ class TransportChannel;
namespace remoting {
namespace protocol {
// TransportChannelSocketAdapter implements net::Socket interface on
// top of libjingle's TransportChannel. It is used by LibjingleTransportFactory
-// to provide net::Socket interface for channels.
-class TransportChannelSocketAdapter : public net::Socket,
+// to provide P2PDatagramSocket interface for channels.
+class TransportChannelSocketAdapter : public P2PDatagramSocket,
public sigslot::has_slots<> {
public:
// Doesn't take ownership of the |channel|. The |channel| must outlive this
@@ -20,10 +20,10 @@ class TransportChannel;
namespace remoting {
namespace protocol {
-// TransportChannelSocketAdapter implements net::Socket interface on
+// TransportChannelSocketAdapter implements P2PDatagramSocket interface on
// top of libjingle's TransportChannel. It is used by LibjingleTransportFactory

Powered by Google App Engine
This is Rietveld 408576698